@@ -9,7 +9,7 @@ require DynaLoader;
 use vars qw($VERSION @ISA $__import @preload);
 @ISA = qw(DynaLoader);
 sub dl_load_flags { 0x00 }
-$VERSION = '1.50';
+$VERSION = '1.51';
 bootstrap Prima $VERSION;
 unless ( UNIVERSAL::can('Prima', 'init')) {
 	$::application = 0;
@@ -279,6 +279,8 @@ L<Prima::Classes> - binder module for the core classes
 
 L<Prima::Drawable> - 2-D graphic interface 
 
+L<Prima::Region> - generic shape for clipping and hit testing
+
 L<Prima::Image>  - bitmap routines 
 
 L<Prima::image-load> - image subsystem and file operations
@@ -365,6 +367,8 @@ L<Prima::ScrollWidget> - scrollable generic document widget
 
 L<Prima::Sliders> - sliding bars, spin buttons and input lines, dial widget etc.
 
+L<Prima::Spinner> - spinner animation
+
 L<Prima::StartupWindow> - a simplistic startup banner window
 
 L<Prima::TextView> - rich text browser widget
@@ -395,6 +399,8 @@ L<Prima::Drawable::CurvedText> - fit text to path
 
 L<Prima::Drawable::Subcanvas> - paint a hierarchy of widgets to any drawable
 
+L<Prima::Drawable::Path> - stroke and fill complex paths
+
 =item Visual Builder
 
 L<VB> - Visual Builder for the Prima toolkit
