@@ -1,17 +1,61 @@
 #
 #  Created by:
 #     Anton Berezin  <tobez@tobez.org>
-#     Dmitry Karasik <dk@plab.ku.dk> 
+#     Dmitry Karasik <dmitry@karasik.eu.org>
 #
 package Prima::Classes;
+use strict;
+use warnings;
 use Prima;
 use Prima::Const;
 
+package Prima::array;
+use base 'Tie::Array';
+
+sub new
+{
+	my ($class, $letter) = @_;
+	die "bad array type" if $letter !~ /^[id]$/;
+	my @tie;
+	my $size = length pack $letter, 0;
+	my $buf = '';
+	tie @tie, $class, $buf, $size, $letter;
+	return \@tie;
+}
+
+sub new_int    { shift->new('i') }
+sub new_double { shift->new('d') }
+
+use constant REF  => 0;
+use constant SIZE => 1;
+use constant PACK => 2;
+
+sub is_array { ((ref tied @{$_[0]}) // '') eq 'Prima::array' }
+
+sub append
+{
+	die "bad array" if grep { !is_array($_) } @_;
+	my ( $a1, $a2 ) = map { tied @$_ } @_;
+	die "bad array" if $a1->[PACK] ne $a2->[PACK];
+	$a1->[REF] .= $a2->[REF];
+}
+
+sub TIEARRAY  { bless \@_, shift }
+sub FETCH     { unpack( $_[0]->[PACK], substr( $_[0]->[REF], $_[1] * $_[0]->[SIZE], $_[0]->[SIZE] )) }
+sub STORE     { substr( $_[0]->[REF], $_[1] * $_[0]->[SIZE], $_[0]->[SIZE], pack( $_[0]->[PACK], $_[2] )) }
+sub FETCHSIZE { length( $_[0]->[REF] ) / $_[0]->[SIZE] }
+sub EXISTS    { $_[1] < FETCHSIZE($_[0]) }
+sub STORESIZE {
+	( $_[1] > FETCHSIZE($_[0]) ) ?
+		(STORE($_[0], $_[1] - 1, 0)) :
+		(substr( $_[0]->[REF], $_[1] * $_[0]->[SIZE] ) = '' )
+}
+sub DELETE    { warn "This array does not implement delete functionaly" }
+
+
 # class Object; base class of all Prima classes
 package Prima::Object;
 use vars qw(@hooks);
-use strict;
-use warnings;
 use Carp;
 
 sub CLONE_SKIP { 1 }
@@ -127,7 +171,6 @@ GENPROC
 
 sub DESTROY {}
 
-# class Component
 package Prima::Component;
 use vars qw(@ISA);
 @ISA = qw(Prima::Object);
@@ -229,7 +272,6 @@ sub find_component
 	return undef;
 }
 
-# class File
 package Prima::File;
 use vars qw(@ISA);
 @ISA = qw(Prima::Component);
@@ -251,6 +293,7 @@ sub profile_default
 	my $def = $_[ 0]-> SUPER::profile_default;
 	my %prf = (
 		file  => undef,
+		fd    => -1,
 		mask  => fe::Read | fe::Write | fe::Exception,
 		owner => undef,
 	);
@@ -299,7 +342,44 @@ sub image
 	}
 }
 
-# class Drawable
+package Prima::Region;
+use vars qw(@ISA);
+@ISA = qw(Prima::Component);
+
+sub origin { (shift->box)[0,1] }
+sub size   { (shift->box)[2,3] }
+sub rect
+{
+	my @box = shift->box;
+	return @box[0,1], $box[0] + $box[2], $box[1] + $box[3];
+}
+
+sub dup
+{
+	my $r = ref($_[0])->new;
+	$r->combine($_[0], rgnop::Copy);
+	return $r;
+}
+
+sub bitmap
+{
+	my ($self, $with_offset, $type) = @_;
+	return undef if $self-> is_empty;
+	my @box = $self->box;
+	my @size = @box[2,3];
+	if ( $with_offset ) {
+		$size[0] += $box[0];
+		$size[1] += $box[1];
+	}
+	my $dbm = Prima::DeviceBitmap->new( size => \@size, type => $type // dbt::Bitmap );
+	$dbm-> clear;
+	$self-> offset( -$box[0], -$box[1]) unless $with_offset;
+	$dbm-> region($self);
+	$self-> offset( $box[0], $box[1]) unless $with_offset;
+	$dbm-> bar(0,0,@size);
+	return $dbm;
+}
+
 package Prima::Drawable;
 use vars qw(@ISA);
 @ISA = qw(Prima::Component);
@@ -333,7 +413,6 @@ sub profile_default
 		region          => undef,
 		rop             => rop::CopyPut,
 		rop2            => rop::NoOper,
-		splinePrecision => 24,
 		textOutBaseline => 0,
 		textOpaque      => 0,
 		translate       => [ 0, 0],
@@ -390,7 +469,18 @@ sub text_out_bidi
 
 sub has_alpha_layer { 0 }
 
-# class Image
+sub spline
+{
+	my $self = shift;
+	$self->polyline( $self->render_spline(@_) );
+}
+
+sub fill_spline
+{
+	my $self = shift;
+	$self->fillpoly( $self->render_spline(@_) );
+}
+
 package Prima::Image;
 use vars qw( @ISA);
 @ISA = qw(Prima::Drawable);
@@ -480,7 +570,24 @@ sub clone
 	return $i;
 }
 
-# class Icon
+sub ui_scale
+{
+	my ($self, %opt) = @_;
+
+	my $zoom = delete($opt{zoom}) // ( $::application ? $::application->uiScaling : 1 );
+	return $self if $zoom == 1.0;
+
+	my $scaling = delete($opt{scaling}) // ist::Quadratic;
+	$self->set(
+		%opt,
+		scaling => $scaling,
+		size => [ map { $_ * $zoom } $self->size ],
+	);
+	return $self;
+}
+
+sub to_region { Prima::Region->new( image => shift ) }
+
 package Prima::Icon;
 use vars qw( @ISA);
 @ISA = qw(Prima::Image);
@@ -536,7 +643,31 @@ sub create_combined
 
 sub has_alpha_layer { shift->maskType == im::bpp8 }
 
-# class DeviceBitmap
+sub ui_scale
+{
+	my ($self, %opt) = @_;
+	
+	my $zoom = delete($opt{zoom}) // ( $::application ? $::application->uiScaling : 1 );
+	return $self if $zoom == 1.0;
+
+	my $argb    = delete($opt{argb})    // ($::application ? $::application-> get_system_value( sv::LayeredWidgets ) : 0);
+	my $scaling = delete($opt{scaling}) // ($argb ? ist::Quadratic : ist::Box );
+
+	if ( $scaling <= ist::Box ) {
+		# don't uglify bitmaps with box scaling where zoom is 1.25 or 2.75
+		$zoom = int($zoom + .5);
+		return if $zoom <= 1.0;
+	}
+
+	$self->set(
+		%opt,
+		scaling => $scaling,
+		size => [ map { $_ * $zoom } $self->size ],
+	);
+
+	return $self;
+}
+
 package Prima::DeviceBitmap;
 use vars qw( @ISA);
 @ISA = qw(Prima::Drawable);
@@ -570,7 +701,6 @@ sub profile_check_in
 
 sub has_alpha_layer { shift->type == dbt::Layered }
 
-# class Timer
 package Prima::Timer;
 use vars qw(@ISA);
 @ISA = qw(Prima::Component);
@@ -594,7 +724,6 @@ sub profile_default
 	return $def;
 }
 
-# class Printer
 package Prima::Printer;
 use vars qw(@ISA);
 @ISA = qw(Prima::Drawable);
@@ -610,7 +739,6 @@ sub profile_default
 	return $def;
 }
 
-# class Widget
 package Prima::Widget;
 use vars qw(@ISA %WidgetProfile @default_font_box);
 @ISA = qw(Prima::Drawable);
@@ -649,6 +777,7 @@ my %RNT = (
 	Show           => nt::Default,
 	Size           => nt::Default,
 	TranslateAccel => nt::Default,
+	SysHandle      => nt::Default,
 	ZOrderChanged  => nt::Default,
 );
 
@@ -1132,7 +1261,6 @@ sub rect_bevel
 
 sub has_alpha_layer { $_[0]-> layered && $_[0]-> is_surface_layered }
 
-# class Window
 package Prima::Window;
 use vars qw(@ISA);
 @ISA = qw(Prima::Widget);
@@ -1158,6 +1286,7 @@ sub profile_default
 		borderStyle           => bs::Sizeable,
 		clipOwner             => 0,
 		growMode              => gm::DontCare,
+		effects               => undef,
 		icon                  => 0,
 		mainWindow            => 0,
 		menu                  => undef,
@@ -1253,7 +1382,6 @@ sub menuDark3DColor      { return shift-> menuColorIndex( ci::Dark3DColor  , @_)
 sub menuLight3DColor     { return shift-> menuColorIndex( ci::Light3DColor , @_);}
 
 
-# class Dialog
 package Prima::Dialog;
 use vars qw(@ISA);
 @ISA = qw(Prima::Window);
@@ -1290,7 +1418,6 @@ sub profile_default
 sub on_create  { $::main_window = $_[0] }
 sub on_destroy { $::application-> close; undef $::main_window }
 
-# class MenuItem
 package Prima::MenuItem;
 
 sub create
@@ -1323,7 +1450,6 @@ sub toggle  {
 	return $i
 }
 
-# class AbstractMenu
 package Prima::AbstractMenu;
 use vars qw(@ISA);
 @ISA = qw(Prima::Component);
@@ -1365,17 +1491,14 @@ sub AUTOLOAD
 	return Prima::MenuItem-> create( $self, $itemName);
 }
 
-# class AccelTable
 package Prima::AccelTable;
 use vars qw(@ISA);
 @ISA = qw(Prima::AbstractMenu);
 
-# class Menu
 package Prima::Menu;
 use vars qw(@ISA);
 @ISA = qw(Prima::AbstractMenu);
 
-# class Popup
 package Prima::Popup;
 use vars qw(@ISA);
 @ISA = qw(Prima::AbstractMenu);
@@ -1453,6 +1576,7 @@ my %RNT = (
 	PasteText   => nt::Action,
 	CopyImage   => nt::Action,
 	PasteImage  => nt::Action,
+	Idle        => nt::Default,
 );
 
 sub notification_types { return \%RNT; }
@@ -1486,6 +1610,7 @@ sub profile_default
 		printerModule  => $unix ? 'Prima::PS::Printer' : '',
 		helpClass      => 'Prima::HelpViewer',
 		helpModule     => 'Prima::HelpViewer',
+		uiScaling      => 0,
 		wantUnicodeInput => 0,
 	);
 	@$def{keys %prf} = values %prf;
