@@ -11,7 +11,6 @@ sub profile_default
 		%{$self-> SUPER::profile_default},
 		style	    => 'drops',
 		active	    => 1,
-		antialias   => 1,
 		buffered    => 1,
 		value	    => 50,
 		showPercent => 1,
@@ -21,19 +20,19 @@ sub profile_default
 sub init
 {
 	my $self = shift;
-
+	
 	# Create the timer for the motion of the spinner
-	$self->{timer} = $self->insert( Timer =>
+	$self->{timer} = $self->insert( Timer => 
 		name	    => 'Timer',
 		timeout     => 200,
 		delegations => ['Tick'],
 	);
-
+	
 	# Init the Spinner
 	my %profile = $self-> SUPER::init(@_);
 	$self->{start_angle} = 0;
 	$self-> $_($profile{$_}) for qw( value showPercent style active color hiliteColor);
-
+	
 	return %profile;
 }
 
@@ -80,8 +79,8 @@ sub on_paint
 	my ($self,$canvas) = @_;
 
 	$canvas->clear;
-
-	my $x		 = $self->width/2;
+		
+	my $x		 = $self->width/2; 
 	my $y		 = $self->height/2;
 	my $min		 = ( $x < $y ) ? $x : $y;
 	my $scale_factor = $min / 12;
@@ -92,7 +91,7 @@ sub on_paint
 		$canvas->color($color2);
 		$canvas->lineWidth(3*$scale_factor);
 		$canvas->ellipse($x, $y, 17.5*$scale_factor,17.5*$scale_factor);
-
+		
 		$canvas->lineWidth(1.5*$scale_factor);
 		$canvas->color($color1);
 		$canvas->lineEnd(le::Square);
@@ -132,11 +131,16 @@ sub on_paint
 
 		$canvas->translate($x, $y);
 
-		my @colors = $canvas->new_gradient( palette => [ $self->color, $self->backColor ] )->colors(8+1);
-		my $fill_spline = sub {
+		my $gradient = $canvas->gradient_realize3d( 8+1, { palette => [ $self->color, $self->backColor ] });
+		my @colors;
+		for ( my $i = 0; $i < @$gradient; $i+=2 ) {
+			push @colors, $gradient->[$i] for 1 .. $gradient->[$i+1];
+		}
+
+		my $fill_spline = sub { 
 			my ( $n, $p ) = @_;
 			$canvas->color( $colors[( $self->{start_angle} + $n) % 8] );
-			$canvas->fill_spline(_scale($p, $scale_factor, $scale_factor), integer => !$self->antialias);
+			$canvas->fill_spline(_scale($p, $scale_factor, $scale_factor));
 		};
 
 		$fill_spline->(7, \@petal2);
@@ -148,25 +152,25 @@ sub on_paint
 		$fill_spline->(1, _h_flip \@petal2);
 		$fill_spline->(0, \@petal1 );
 	} elsif ( $self->{style} eq 'spiral') {
-		my $r = sqrt(2) - 1;
-		my @s = ( 1, 0,    1-.00225, $r,      $r, 0.95+.00225, 0, .95);
-		my @z = ( 0, 1.05, $r+.018, 1.05-.02, 1+.005, $r+.018, 1, 0);
+		my $d1	 = 0.8;
+		my $d2	 = 0.2;
+		my $dx	 = $d2 / 4;
 
+		$canvas->fillWinding(1);
 		$canvas->translate($x, $y);
-		my $p = $canvas-> new_path( subpixel => 1 )->
-			scale($scale_factor * 9)->
-			rotate(-$self->{start_angle});
-		$p->spline(\@s);
-		$p->save;
-			$p->rotate(90)->scale(0.95)->spline(\@s) for 1..3;
-		$p->restore;
-		$p->arc(1.05 ** 4 - 1.20 + 1, 0, .4, .4, 180, 0);
-		$p->save;
-			$p->scale(1.05 ** 4);
-			$p->rotate(-90)->scale(1 / 1.05)->spline(\@z) for 1..3;
-		$p->restore;
-		$p->spline(\@z);
-		$p->fill;
+		$canvas-> new_path->
+			scale($scale_factor * 22)->
+			rotate(-$self->{start_angle})->
+			arc( 0, 0, $d1 + $dx * 0, $d1 + $dx * 1, 0, 90)->
+			arc( 0, 0, $d1 + $dx * 2, $d1 + $dx * 1, 90, 180)->
+			arc( 0, 0, $d1 + $dx * 2, $d1 + $dx * 3, 180, 270)->
+			arc( 0, 0, $d1 + $dx * 4, $d1 + $dx * 3, 270, 360)->
+			arc( $d1/2, 0, $d2, $d2, 0, 180)->
+			arc( 0, 0, $d1 - $dx * 4, $d1 - $dx * 3, 360, 270)->
+			arc( 0, 0, $d1 - $dx * 2, $d1 - $dx * 3, 270, 180)->
+			arc( 0, 0, $d1 - $dx * 2, $d1 - $dx * 1, 180, 90)->
+			arc( 0, 0, $d1 - $dx * 0, $d1 - $dx * 1, 90, 0)->
+		fill;
 	}
 }
 
@@ -191,12 +195,12 @@ sub style
 	$self-> repaint;
 }
 
-sub update_value
+sub update_value     
 {
 	my $self = shift;
 	$self->{angle1} = (360 + $self->{start_angle} - $self->{value} * 360 / 100) % 360;
 	$self->{angle2} = $self->{start_angle};
-	$self->{angle2} += 360 if $self->{value} >= 100.0 || $self->{angle1} > $self->{angle2};
+	$self->{angle2} += 360 if $self->{value} >= 100.0;
 }
 
 sub value
@@ -235,70 +239,70 @@ __END__
 
 =head1 NAME
 
-Prima::Spinner - spinner animation widget
+Prima::Spinner - Show a spinner animation
 
 =head1 SYNOPSIS
 
   use Prima qw(Application Buttons Spinner);
 
   my $mw = Prima::MainWindow->new(
-	size      => [200, 400],
-	text      => 'Button Example'
-  );
+		size => [200, 400],
+		text => 'Button Example');
 
   my $spinner = $mw->insert('Spinner',
-	style     => 'drops',
-	size      => [200,400],
-	growMode  => gm::Center
+	style => 'drops',
+	size => [200,400],
+	growMode => gm::Center
   );
 
   my $button = $mw->insert(
 	'Button',
-	text      => 'Start/Stop',
+	text => 'Start/Stop',
 	checkable => 1,
-	checked   => 1,
-	origin    => [0,0],
-	onClick   => sub { $spinner->toggle },
-	growMode  => gm::XCenter
+	checked => 1,
+	origin => [0,0],
+	onClick => sub { $spinner->toggle },
+	growMode => gm::XCenter
   );
 
-  Prima->run;
-
-=for podview <img src="spinner.gif">
-
-=for html <p><img src="https://raw.githubusercontent.com/dk/Prima/master/pod/Prima/spinner.gif">
+  run Prima;
 
 =head1 DESCRIPTION
 
-Prima::Spinner provides a simple spinning animation in three different designs
-and the opportunity to specify the colors of the spinning animation. This is
-useful to show the progress of a running process.
+Prima::Spinner provides a simple spinning animation with two designs and the
+opportunity to specify the colors of the spinning animation. This is useful to
+show an indeterminate progress of a running process.
 
 =head1 USAGE
 
+You can determine the following properties:
+
 =head2 Properties
 
 =over
 
 =item active [BOOLEAN]
 
-Manages whether the spinning animation is active or not.
+If now parameter is passed, by this method you can get the active state of the
+spinning widget. '1' means that the spinner is running, '0' that it is stopped.
+With C<active(1)> you can start the spinner animation, with C<active(0)> you
+can stop it.
 
 =item color COLOR
 
 Inherited from L<Prima::Widget>. C<color> manages the basic foreground color.
-For the spinner widget, this means the background color of the circle
-or the color of the drops.
+Concrete for the spinner widget this means the background color of the circle
+or the color of the active drops.
 
 =item hiliteColor COLOR
 
-Inherited from L<Prima::Widget>. The color is used to draw alternate foreground
-areas with high contrast. For the spinner widget, this defines the color of the
-arc. Only for the I<circle> style.
+Inherited from L<Prima::Widget>. The color used to draw alternate foreground
+areas with high contrast. For the spinner widget this means the color of the
+arc. Only for I<circle> style.
 
 =item showPercent BOOLEAN
 
-If set, displays completion percent as text. Only for the I<circle> style.
+If set, displays completion percent as text. Only for I<circle> style.
 
 =item start
 
@@ -310,13 +314,11 @@ Same as C< active(0) >
 
 =item style STRING
 
-C<style> can be 'drops', 'circle' or 'spiral'. C<drops> shows drops with fading
-colors. The C<circle> style features an arc moving around a circle. C<spiral>
-shows a spinning spiral. The default is 'drops'.
+C<style> can be 'drops', 'circle' or 'spiral'. C<'drops'> shows drops that switches consecutively the color. With C<'circle'> an arc moving around a circle is shown. C<'spiral'> shows a spinning spiral. The default is 'drops'.
 
 =item value INT
 
-An integer value between 0 and 100, shows completion percentage. Only for the I<circle> style.
+Integer between 0 and 100, showing completion perentage. Only for I<circle> style.
 
 =item toggle
 
@@ -332,4 +334,13 @@ L<Prima>. L<Prima::Widget>, F<examples/spinner.pl>
 
 Maximilian Lika
 
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2017 by Maximilian Lika
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.22.2 or,
+at your option, any later version of Perl 5 you may have available.
+
+
 =cut
