@@ -6,7 +6,7 @@
 #define POLLUTE_NAME_SPACE 1
 #endif
 
-#define PRIMA_CORE_VERSION 2016063001
+#define PRIMA_CORE_VERSION 2017030901
 
 #define PRIMA_VERSION_BOOTCHECK \
 	if(apc_get_core_version()!=PRIMA_CORE_VERSION) \
@@ -381,14 +381,6 @@ typedef struct { double re, im; } DComplex;
 typedef struct { float  r,  ph; } TrigComplex;
 typedef struct { double r,  ph; } TrigDComplex;
 
-typedef struct _Rect2
-{
-	int x;
-	int y;
-	int width;
-	int height;
-} Rect2, *PRect2;
-
 #ifdef __cplusplus
 #define nil       NULL
 #else
@@ -1382,6 +1374,8 @@ SvBOOL( SV *sv)
 #define CPopup(h)                       (PPopup(h)-> self)
 #define PPrinter(h)                     TransmogrifyHandle(Printer,(h))
 #define CPrinter(h)                     (PPrinter(h)-> self)
+#define PRegion(h)                      TransmogrifyHandle(Region,(h))
+#define CRegion(h)                      (PRegion(h)-> self)
 #define PTimer(h)                       TransmogrifyHandle(Timer,(h))
 #define CTimer(h)                       (PTimer(h)-> self)
 #define PWidget(h)                      TransmogrifyHandle(Widget,(h))
@@ -1478,6 +1472,9 @@ prima_array_tie( SV * array, size_t size_of_entry, char * letter);
 extern Bool
 prima_array_parse( SV * sv, void ** ref, size_t * length, char ** letter);
 
+extern Bool
+prima_read_point( SV *rv_av, int * pt, int number, char * error);
+
 /* OS types */
 #define APC(const_name) CONSTANT(apc,const_name)
 START_TABLE(apc,UV)
@@ -1912,7 +1909,7 @@ apc_application_get_os_info( char *system, int slen,
 extern Point
 apc_application_get_size( Handle self);
 
-extern Rect2 *
+extern Box *
 apc_application_get_monitor_rects( Handle self, int * nrects);
 
 extern Bool
@@ -3193,7 +3190,85 @@ typedef struct _TextWrapRec {
 	PList    * unicode;                 /* NB - .ascii can be present in .unicode ! */
 } TextWrapRec, *PTextWrapRec;
 
-/* gpi functions underplace */
+/* regions */
+
+#define rgnEmpty     0
+#define rgnRectangle 1
+#define rgnPolygon   2
+#define rgnImage     3
+
+typedef struct {
+	int n_points;
+	Bool winding;
+	Point* points;
+} PolygonRegionRec;
+
+typedef struct {
+	int type;
+	union {
+		Box box;
+		PolygonRegionRec polygon;
+		Handle image;
+	} data;
+} RegionRec, *PRegionRec;
+
+#define RGNOP(const_name) CONSTANT(rgnop,const_name)
+START_TABLE(rgnop,UV)
+#define rgnopCopy       0
+RGNOP(Copy)
+#define rgnopIntersect  1
+RGNOP(Intersect)
+#define rgnopUnion      2
+RGNOP(Union)
+#define rgnopXor        3
+RGNOP(Xor)
+#define rgnopDiff       4
+RGNOP(Diff)
+END_TABLE(rgnop,UV)
+#undef RGNOP
+
+#define RGN(const_name) CONSTANT(rgn,const_name)
+START_TABLE(rgn,UV)
+#define rgnOutside      0
+RGN(Outside)
+#define rgnInside       1
+RGN(Inside)
+#define rgnPartially    2
+RGN(Partially)
+END_TABLE(rgn,UV)
+#undef RGN
+
+extern Bool
+apc_region_create( Handle self, PRegionRec rec);
+
+extern Bool
+apc_region_destroy( Handle self);
+
+extern Bool
+apc_region_offset( Handle self, int dx, int dy);
+
+extern Bool
+apc_region_combine( Handle self, Handle other_region, int rgnop);
+
+extern Bool
+apc_region_point_inside( Handle self, Point p);
+
+extern int
+apc_region_rect_inside( Handle self, Rect r);
+
+extern Bool
+apc_region_equals( Handle self, Handle other_region);
+
+extern Box
+apc_region_get_box( Handle self);
+
+extern Bool
+apc_region_is_empty( Handle self);
+
+extern ApiHandle
+apc_region_get_handle( Handle self);
+
+/* gp functions */
 extern Bool
 apc_gp_init( Handle self);
 
@@ -3320,7 +3395,7 @@ extern PRGBColor
 apc_gp_get_physical_palette( Handle self, int * colors);
 
 extern Bool
-apc_gp_get_region( Handle self, Handle mask);
+apc_gp_get_region( Handle self, Handle rgn);
 
 extern Point
 apc_gp_get_resolution( Handle self);
@@ -3380,7 +3455,7 @@ extern Bool
 apc_gp_set_palette( Handle self);
 
 extern Bool
-apc_gp_set_region( Handle self, Handle mask);
+apc_gp_set_region( Handle self, Handle rgn);
 
 extern Bool
 apc_gp_set_rop( Handle self, int rop);
