@@ -1,6 +1,7 @@
 #include "apricot.h"
 #include "Drawable.h"
-#include "Image.h"
+#include "Icon.h"
+#include "Region.h"
 #include <Drawable.inc>
 
 #ifdef __cplusplus
@@ -436,7 +437,7 @@ Drawable_text_out( Handle self, SV * text, int x, int y)
 	return ok;
 }
 
-static void *
+void *
 read_array( SV * points, char * procName, Bool integer, int div, int min, int max, int * n_points )
 {
 	AV * av;
@@ -451,19 +452,19 @@ read_array( SV * points, char * procName, Bool integer, int div, int min, int ma
 	av = ( AV *) SvRV( points);
 	count = av_len( av) + 1;
 	if ( min == max && count != min * div ) {
-		warn("Drawable::%s: array must contain %d elements", procName, min * div);
+		warn("%s: array must contain %d elements", procName, min * div);
 		return NULL;
 	}
 	if ( count < min * div ) {
-		warn("Drawable::%s: array must contain at least %d elements", procName, min * div);
+		warn("%s: array must contain at least %d elements", procName, min * div);
 		return NULL;
 	}
 	if ( max >= 0 && count > max * div ) {
-		warn("Drawable::%s: array must contain maximum %d elements", procName, max * div);
+		warn("%s: array must contain maximum %d elements", procName, max * div);
 		return NULL;
 	}
 	if ( count % div != 0 ) {
-		warn("Drawable::%s: number of elements in an array must be a multiple of %d", procName, div);
+		warn("%s: number of elements in an array must be a multiple of %d", procName, div);
 		return NULL;
 	}
 	if ( n_points) 
@@ -495,7 +496,7 @@ read_array( SV * points, char * procName, Bool integer, int div, int min, int ma
 		SV** psv = av_fetch( av, i, 0);
 		if ( psv == NULL) {
 			free( p);
-			warn("Array panic on item %d on Drawable::%s", i, procName);
+			warn("Array panic on item %d on %s", i, procName);
 			return NULL;
 		}
 		if ( integer )
@@ -545,8 +546,6 @@ Drawable_bars( Handle self, SV * rects)
 	return ret;
 }
 
-#define procName "Drawable::render_spline"
-
 /* 
 
 Render B-spline
@@ -679,7 +678,7 @@ Drawable_render_spline( SV * obj, SV * points, HV * profile)
 	} else 
 		precision = 24;
 	
-	p = (NPoint*) read_array( points, procName, false, 2, degree + 1, -1, &n_points);
+	p = (NPoint*) read_array( points, "Drawable::render_spline", false, 2, degree + 1, -1, &n_points);
 	if ( !p) goto EXIT;
 
 	/* closed curve will need at least one extra point and unclamped default knot set */
@@ -771,7 +770,6 @@ EXIT:
 		return newRV_noinc(( SV *) newAV());
 	}
 }
-#undef procName
 
 int
 Drawable_get_text_width( Handle self, SV * text, Bool addOverhang)
@@ -1372,25 +1370,32 @@ Drawable_region( Handle self, Bool set, Handle mask)
 	if ( var-> stage > csFrozen) return nilHandle;
 
 	if ( set) {
+		if ( mask && kind_of( mask, CRegion)) {
+			apc_gp_set_region( self, mask);
+			return nilHandle;
+		}
+
 		if ( mask && !kind_of( mask, CImage)) {
 			warn("Illegal object reference passed to Drawable::region");
 			return nilHandle;
 		}
 
-		if ( mask && (( PImage( mask)-> type & imBPP) != imbpp1)) {
-			Handle i = CImage( mask)-> dup( mask);
-			++SvREFCNT( SvRV( PImage( i)-> mate));
-			CImage( i)-> set_conversion( i, ictNone);
-			CImage( i)-> set_type( i, imBW);
-			apc_gp_set_region( self, i);
-			--SvREFCNT( SvRV( PImage( i)-> mate));
-			Object_destroy( i);
+		if ( mask ) {
+			Handle region;
+			HV * profile = newHV();
+
+			pset_H( image, mask );
+			region = Object_create("Prima::Region", profile);
+			sv_free(( SV *) profile);
+
+			apc_gp_set_region(self, region);
+			Object_destroy(region);
 		} else
-			apc_gp_set_region( self, mask);
+			apc_gp_set_region(self, nilHandle);
 
 	} else if ( apc_gp_get_region( self, nilHandle)) {
 		HV * profile = newHV();
-		Handle i = Object_create( "Prima::Image", profile);
+		Handle i = Object_create( "Prima::Region", profile);
 		sv_free(( SV *) profile);
 		apc_gp_get_region( self, i);
 		--SvREFCNT( SvRV((( PAnyObject) i)-> mate));
