@@ -2,6 +2,7 @@
 #include "Application.h"
 #include "Icon.h"
 #include "Popup.h"
+#include "Region.h"
 #include "Widget.h"
 #include "Window.h"
 #include <Widget.inc>
@@ -1822,9 +1823,9 @@ Widget_set_centered( Handle self, Bool x, Bool y)
 
 	if ( parent == application ) {
 		int i, nrects = 0;
-		Rect2 *best = nil, *rects = apc_application_get_monitor_rects( application, &nrects);
+		Box *best = nil, *rects = apc_application_get_monitor_rects( application, &nrects);
 		for ( i = 0; i < nrects; i++) {
-			Rect2 * curr = rects + i;
+			Box * curr = rects + i;
 			if ( best == nil || best-> x > curr->x || best->y > curr->y)
 				best = curr;
 		}
@@ -2046,33 +2047,6 @@ single_color_notify ( Handle self, Handle child, void * color)
 	return false;
 }
 
-Bool
-prima_read_point( SV *rv_av, int * pt, int number, char * error)
-{
-	SV ** holder;
-	int i;
-	AV *av;
-	Bool result = true;
-
-	if ( !rv_av || !SvROK( rv_av) || ( SvTYPE( SvRV( rv_av)) != SVt_PVAV)) {
-		result = false;
-		if ( error) croak( "%s", error);
-	} else {
-		av = (AV*)SvRV(rv_av);
-		for ( i = 0; i < number; i++) {
-			holder = av_fetch( av, i, 0);
-			if ( holder)
-				pt[i] = SvIV( *holder);
-			else {
-				pt[i] = 0;
-				result = false;
-				if ( error) croak( "%s", error);
-			}
-		}
-	}
-	return result;
-}
-
 static Bool
 auto_enable_children( Handle self, Handle child, void * enable)
 {
@@ -2819,7 +2793,7 @@ Widget_shape( Handle self, Bool set, Handle mask)
 	if ( !set) {
 		if ( apc_widget_get_shape( self, nilHandle)) {
 			HV * profile = newHV();
-			Handle i = Object_create( "Prima::Image", profile);
+			Handle i = Object_create( "Prima::Region", profile);
 			sv_free(( SV *) profile);
 			apc_widget_get_shape( self, i);
 			--SvREFCNT( SvRV((( PAnyObject) i)-> mate));
@@ -2828,21 +2802,28 @@ Widget_shape( Handle self, Bool set, Handle mask)
 			return nilHandle;
 	}
 
-	if ( mask && !kind_of( mask, CImage)) {
-		warn("Illegal object reference passed to Widget::shape");
+	if ( mask && kind_of( mask, CRegion)) {
+		apc_widget_set_shape( self, mask);
 		return nilHandle;
 	}
 
-	if ( mask && (( PImage( mask)-> type & imBPP) != imbpp1)) {
-		Handle i = CImage( mask)-> dup( mask);
-		++SvREFCNT( SvRV( PImage( i)-> mate));
-		CImage( i)-> set_conversion( i, ictNone);
-		CImage( i)-> set_type( i, imBW);
-		apc_widget_set_shape( self, i);
-		--SvREFCNT( SvRV( PImage( i)-> mate));
-		Object_destroy( i);
+	if ( mask && !kind_of( mask, CImage)) {
+		warn("Illegal object reference passed to Drawable::region");
+		return nilHandle;
+	}
+
+	if ( mask ) {
+		Handle region;
+		HV * profile = newHV();
+
+		pset_H( image, mask );
+		region = Object_create("Prima::Region", profile);
+		sv_free(( SV *) profile);
+
+		apc_widget_set_shape( self, region);
+		Object_destroy(region);
 	} else
-		apc_widget_set_shape( self, mask);
+		apc_widget_set_shape( self, nilHandle);
 
 	return nilHandle;
 }
