@@ -26,6 +26,7 @@
 #include "Timer.h"
 #include "Utils.h"
 #include "Printer.h"
+#include "Region.h"
 #include "img_conv.h"
 
 
@@ -627,6 +628,7 @@ XS(Prima_init)
 		register_notifications((PVMT)CWindow);
 		register_notifications((PVMT)CApplication);
 		register_notifications((PVMT)CPrinter);
+		register_notifications((PVMT)CRegion);
 		prima_init_ok++;
 	}
 	
@@ -1259,6 +1261,8 @@ register_constants( void)
 	register_ps_constants();
 	register_scr_constants();
 	register_dbt_constants();
+	register_rgn_constants();
+	register_rgnop_constants();
 }
 
 XS( Object_alive_FROMPERL);
@@ -1328,6 +1332,7 @@ if (sizeof(s1) != (s2)) { \
 	register_Application_Class();
 	register_Timer_Class();
 	register_Printer_Class();
+	register_Region_Class();
 
 	ST(0) = &PL_sv_yes;
 	XSRETURN(1);
@@ -1928,6 +1933,34 @@ prima_array_parse( SV * sv, void ** ref, size_t * length, char ** letter)
 	return true;
 }
 
+Bool
+prima_read_point( SV *rv_av, int * pt, int number, char * error)
+{
+	SV ** holder;
+	int i;
+	AV *av;
+	Bool result = true;
+
+	if ( !rv_av || !SvROK( rv_av) || ( SvTYPE( SvRV( rv_av)) != SVt_PVAV)) {
+		result = false;
+		if ( error) croak( "%s", error);
+	} else {
+		av = (AV*)SvRV(rv_av);
+		for ( i = 0; i < number; i++) {
+			holder = av_fetch( av, i, 0);
+			if ( holder)
+				pt[i] = SvIV( *holder);
+			else {
+				pt[i] = 0;
+				result = false;
+				if ( error) croak( "%s", error);
+			}
+		}
+	}
+	return result;
+}
+
+
 #ifdef __cplusplus
 }
 #endif
