@@ -1896,32 +1896,34 @@ process_timers(void)
 	struct timeval t;
 	PTimerSysData timer;
 
-	if ( !guts. oldest) return 0;
-
 	gettimeofday( &t, nil);
-	if ( guts. oldest-> when. tv_sec > t. tv_sec || (
-		guts. oldest-> when. tv_sec == t. tv_sec &&
-		guts. oldest-> when. tv_usec > t. tv_usec
-	))
-		return 0;
-	
-	timer = guts. oldest;
-	apc_timer_start( timer-> who);
-	if ( timer-> who == CURSOR_TIMER) {
-		prima_cursor_tick();
-	} else if ( timer-> who == MENU_TIMER) {
-		apc_timer_stop( MENU_TIMER);
-		if ( guts. currentMenu) {
-			XEvent ev;
-			ev. type = MenuTimerMessage;
-			prima_handle_menu_event( &ev, M(guts. currentMenu)-> w-> w, guts. currentMenu);
+	while (1) {
+		if ( !guts. oldest) return 0;
+
+		if ( guts. oldest-> when. tv_sec > t. tv_sec || (
+			guts. oldest-> when. tv_sec == t. tv_sec &&
+			guts. oldest-> when. tv_usec > t. tv_usec
+		))
+			return 0;
+		
+		timer = guts. oldest;
+		apc_timer_start( timer-> who);
+		if ( timer-> who == CURSOR_TIMER) {
+			prima_cursor_tick();
+		} else if ( timer-> who == MENU_TIMER) {
+			apc_timer_stop( MENU_TIMER);
+			if ( guts. currentMenu) {
+				XEvent ev;
+				ev. type = MenuTimerMessage;
+				prima_handle_menu_event( &ev, M(guts. currentMenu)-> w-> w, guts. currentMenu);
+				events++;
+			}
+		} else if ( timer-> who == MENU_UNFOCUS_TIMER) {
+			prima_end_menu();
+		} else {
+			prima_simple_message( timer-> who, cmTimer, false);
 			events++;
 		}
-	} else if ( timer-> who == MENU_UNFOCUS_TIMER) {
-		prima_end_menu();
-	} else {
-		prima_simple_message( timer-> who, cmTimer, false);
-		events++;
 	}
 	return events;
 }
@@ -2039,13 +2041,9 @@ handle_queued_events( Bool careOfApplication )
 	int events = 0;
 
 	events += send_queued_x_events(careOfApplication);
-	fprintf(stderr, "%s.%d: %d\n", __FILE__, __LINE__, events);
 	events += perform_pending_paints();
-	fprintf(stderr, "%s.%d: %d\n", __FILE__, __LINE__, events);
 	events += send_pending_events();
-	fprintf(stderr, "%s.%d: %d\n", __FILE__, __LINE__, events);
 	events += process_timers();
-	fprintf(stderr, "%s.%d: %d\n", __FILE__, __LINE__, events);
 
 	return events;
 }
@@ -2063,39 +2061,27 @@ prima_one_loop_round( int wait, Bool careOfApplication)
 	while ( 1 ) {
 		int events;
 		events = handle_queued_events(careOfApplication);
-		fprintf(stderr, "%s.%d: %d\n", __FILE__, __LINE__, events);
 		t. tv_sec = 0;
 		t. tv_usec = 0;
 		events += process_file_events(&x_events_pending, &t);
-		fprintf(stderr, "%s.%d: %d\n", __FILE__, __LINE__, events);
 		if ( x_events_pending && ( application || !careOfApplication) ) {
 			x_flush();
 			events += handle_queued_events(careOfApplication);
-			fprintf(stderr, "%s.%d: %d\n", __FILE__, __LINE__, events);
 		}
-		if ( wait == WAIT_NEVER || ( events > 0 && wait == WAIT_IF_NONE)) {
-			fprintf(stderr, "%s.%d: %d\n", __FILE__, __LINE__, events);
+		if ( wait == WAIT_NEVER || ( events > 0 && wait == WAIT_IF_NONE))
 			return true;
-		}
-		if ( !application || guts. applicationClose) {
-			fprintf(stderr, "%s.%d: %d\n", __FILE__, __LINE__, events);
+		if ( !application || guts. applicationClose)
 			return false;
-		}
-		if ( events == 0 ) {
-			fprintf(stderr, "%s.%d: %d\n", __FILE__, __LINE__, events);
+		if ( events == 0 )
 			break;
-		}
 	}
 
 	/* wait for events */
 	prima_simple_message( application, cmIdle, false);
 	process_file_events(&x_events_pending, select_timeout(&timeout));
-	if ( x_events_pending && ( application || !careOfApplication) )  {
-		fprintf(stderr, "%s.%d\n", __FILE__, __LINE__);
+	if ( x_events_pending && ( application || !careOfApplication) )
 		x_flush();
-	}
 	handle_queued_events(careOfApplication);
-	fprintf(stderr, "%s.%d: %d\n", __FILE__, __LINE__, application != nilHandle);
 
 	return application != nilHandle;
 }
