@@ -292,9 +292,13 @@ xlfd_parse_font( char * xlfd_name, PFontInfo info, Bool do_vector_fonts)
 			}
 		}
 		if ( *c == '-') {
-			/* advance through SETWIDTH_NAME; just skip it;  XXX */
-			++c;
+			/* advance through SETWIDTH_NAME */
+			b = ++c;
 			while ( *c && *c != '-') c++;
+			if ( c-b == 9 && strncasecmp( b, "condensed", 9) == 0) {
+				info-> font. style |= fsThin;
+				style++;
+			}
 		}
 		if ( *c == '-') {
 			/* advance through ADD_STYLE_NAME; just skip it;  XXX */
@@ -633,6 +637,8 @@ prima_init_font_subsystem( char * error_buf)
 					guts. locale[0] = 0;
 			}
 		}
+		if ( strcmp( guts. locale, "utf-8" ) == 0 )
+			strcpy( guts. locale, "iso10646-1");
 	}
 	
 #ifdef USE_XFT
@@ -649,7 +655,7 @@ prima_init_font_subsystem( char * error_buf)
 		free( do_default_font);
 		do_default_font = nil;
 	} else if ( !apc_fetch_resource( "Prima", "", "Font", "font", 
-									nilHandle, frFont, &guts. default_font)) {
+		nilHandle, frFont, &guts. default_font)) {
 		fill_default_font( &guts. default_font);
 		apc_font_pick( application, &guts. default_font, &guts. default_font);
 		guts. default_font. pitch = fpDefault;
@@ -1475,6 +1481,8 @@ query_diff( PFontInfo fi, PFont f, char * lcname, int selector)
 	} else if ( !fi->  flags. style) {
 		diff += 2000.0;
 	} else {
+		if (( f-> style & fsThin) != ( fi-> font. style & fsThin))
+			diff += 1500;
 		if (( f-> style & fsBold) != ( fi-> font. style & fsBold))
 			diff += 3000;
 		if (( f-> style & fsItalic) != ( fi-> font. style & fsItalic))
