@@ -1331,39 +1331,6 @@ apc_gp_get_physical_palette( Handle self, int * colors)
 	return p;
 }
 
-Bool
-apc_gp_get_region( Handle self, Handle mask)
-{
-	DEFXX;
-	int depth;
-
-	if ( !XF_IN_PAINT(XX)) return false;
-
-	if ( !mask) 
-		return XX-> clip_mask_extent. x != 0 && XX-> clip_mask_extent. y != 0;
-		
-	if ( XX-> clip_mask_extent. x == 0 || XX-> clip_mask_extent. y == 0)
-		return false;
-
-	XSetClipOrigin( DISP, XX-> gc, 0, 0);
-
-	depth = XT_IS_BITMAP(XX) ? 1 : guts. qdepth;
-	CImage( mask)-> create_empty( mask, XX-> clip_mask_extent. x, XX-> clip_mask_extent. y, depth);
-	CImage( mask)-> begin_paint( mask);
-	XCHECKPOINT;
-	XSetForeground( DISP, XX-> gc, ( depth == 1) ? 1 : guts. monochromeMap[1]);
-	XFillRectangle( DISP, X(mask)-> gdrawable, XX-> gc, 0, 0, XX-> clip_mask_extent.x + 1, XX-> clip_mask_extent.y + 1);
-	XCHECKPOINT;
-	XX-> flags. brush_fore = 0;
-	CImage( mask)-> end_paint( mask);
-	XCHECKPOINT;
-	if ( depth != 1) CImage( mask)-> set_type( mask, imBW);
-
-	XSetClipOrigin( DISP, XX-> gc, XX-> btransform.x, 
-		- XX-> btransform. y + XX-> size. y - XX-> clip_mask_extent.y);
-	return true;
-}
-
 Bool
 apc_gp_line( Handle self, int x1, int y1, int x2, int y2)
 {
@@ -1455,134 +1422,6 @@ apc_gp_set_palette( Handle self)
 	return prima_palette_replace( self, false);
 }
 
-Region
-region_create( Handle mask)
-{
-	unsigned long w, h, x, y, size = 256, count = 0;
-	Region    rgn = None;
-	Byte       * idata;
-	XRectangle * current, * rdata;
-	Bool      set = 0;
-
-	if ( !mask)
-		return None;
-
-	w = PImage( mask)-> w;
-	h = PImage( mask)-> h;
-	/*
-		XUnionRegion is actually SLOWER than the image scan - 
-		- uncomment if this is wrong
-	if ( X( mask)-> cached_region) {
-		rgn = XCreateRegion();
-		XUnionRegion( rgn, X( mask)-> cached_region, rgn);
-		return rgn;
-	}
-	*/
-
-	idata  = PImage( mask)-> data + PImage( mask)-> dataSize - PImage( mask)-> lineSize;
-
-	rdata = ( XRectangle*) malloc( size * sizeof( XRectangle));
-	if ( !rdata) return None;
-
-	count = 0;
-	current = rdata;
-	current--;
-
-	for ( y = 0; y < h; y++) {
-		for ( x = 0; x < w; x++) {
-			if ( idata[ x >> 3] == 0) {
-				x += 7;
-				continue;
-			}
-			if ( idata[ x >> 3] & ( 1 << ( 7 - ( x & 7)))) {
-				if ( set && current-> y == y && current-> x + current-> width == x)
-					current-> width++;
-				else {
-					set = 1;
-					if ( count >= size) {
-						void * xrdata = realloc( rdata, ( size *= 3) * sizeof( XRectangle));
-						if ( !xrdata) {
-							free( rdata); 
-							return None;
-						}
-						rdata = xrdata;
-						current = rdata;
-						current += count - 1;
-					}
-					count++;
-					current++;
-					current-> x   = x;
-					current-> y   = y;
-					current-> width  = 1;
-					current-> height = 1;
-				}
-			}
-		}
-		idata -= PImage( mask)-> lineSize;
-	}
-
-	if ( set) {
-		rgn = XCreateRegion();
-		for ( x = 0, current = rdata; x < count; x++, current++) 
-			XUnionRectWithRegion( current, rgn, rgn);
-		/*
-		X( mask)-> cached_region = XCreateRegion();
-		XUnionRegion( X( mask)-> cached_region, rgn, X( mask)-> cached_region);
-		*/
-	}
-	free( rdata);
-
-	return rgn;
-}
-
-Bool
-apc_gp_set_region( Handle self, Handle mask)
-{
-	DEFXX;
-	Region region;
-	PImage img;
-
-	if ( PObject( self)-> options. optInDrawInfo) return false;
-	if ( !XF_IN_PAINT(XX)) return false;
-
-	if (mask == nilHandle) {
-		Rect r;
-	EMPTY:
-		r. left   = 0;
-		r. bottom = 0;
-		r. right  = XX-> size. x;
-		r. top    = XX-> size. y;
-		return apc_gp_set_clip_rect( self, r);
-	}
-	img = PImage(mask);
-	XX-> clip_rect. width = XX-> clip_mask_extent. x = img-> w;
-	XX-> clip_rect. height = XX-> clip_mask_extent. y = img-> h;
-	XX-> clip_rect. x = 0;
-	XX-> clip_rect. y = REVERT(img-> h);
-	if ( !( region = region_create( mask))) goto EMPTY;
-	/* offset region if drawable is buffered */
-	XOffsetRegion( region, XX-> btransform. x, XX-> size.y - img-> h - XX-> btransform. y);
-	/* otherwise ( and only otherwise ), and if there's a
-		X11 clipping, intersect the region with it. X11 clipping
-		must not mix with the buffer clipping */
-	if (( !XX-> udrawable || XX-> udrawable == XX-> gdrawable) && 
-		XX-> paint_region) 
-		XIntersectRegion( region, XX-> paint_region, region);
-	XSetRegion( DISP, XX-> gc, region);
-	if ( XX-> flags. kill_current_region) 
-		XDestroyRegion( XX-> current_region);
-	XX-> flags. kill_current_region = 1;
-	XX-> current_region = region;
-	XX-> flags. xft_clip = 0;
-#ifdef USE_XFT
-	if ( XX-> xft_drawable) prima_xft_update_region( self);
-#endif
-#ifdef HAVE_X11_EXTENSIONS_XRENDER_H
-	if ( XX-> argb_picture ) XRenderSetPictureClipRegion(DISP, XX->argb_picture, region);
-#endif
-	return true;
-}
-
 Bool
 apc_gp_set_pixel( Handle self, int x, int y, Color color)
 {
@@ -1917,49 +1756,6 @@ apc_gp_get_color( Handle self)
 	return ( XF_IN_PAINT(XX)) ? XX-> fore. color : prima_map_color(XX-> saved_fore, nil);
 }
 
-/* returns rect in X coordinates BUT without menuHeight deviation */
-void
-prima_gp_get_clip_rect( Handle self, XRectangle *cr, Bool for_internal_paints)
-{
-	DEFXX;
-	XRectangle r;
-
-	cr-> x = 0;
-	cr-> y = 0;
-	cr-> width = XX-> size.x;
-	cr-> height = XX-> size.y;
-	if ( XF_IN_PAINT(XX) && XX-> paint_region) {
-		XClipBox( XX-> paint_region, &r);
-		prima_rect_intersect( cr, &r);
-	}
-	if ( XX-> clip_rect. x != 0
-		|| XX-> clip_rect. y != 0
-		|| XX-> clip_rect. width != XX-> size.x
-		|| XX-> clip_rect. height != XX-> size.y) {
-		prima_rect_intersect( cr, &XX-> clip_rect);
-	}
-
-	if ( for_internal_paints) {
-		cr-> x += XX-> btransform. x;
-		cr-> y -= XX-> btransform. y;
-	}
-}
-
-Rect
-apc_gp_get_clip_rect( Handle self)
-{
-	DEFXX;
-	XRectangle cr;
-	Rect r;
-
-	prima_gp_get_clip_rect( self, &cr, 0);
-	r. left = cr. x;
-	r. top = XX-> size. y - cr. y - 1;
-	r. bottom = r. top - cr. height + 1;
-	r. right = cr. x + cr. width - 1;
-	return r;
-}
-
 PFontABC
 prima_xfont2abc( XFontStruct * fs, int firstChar, int lastChar)
 {
@@ -2404,47 +2200,6 @@ apc_gp_get_text_out_baseline( Handle self)
 	}
 }
 
-Bool
-apc_gp_set_clip_rect( Handle self, Rect clipRect)
-{
-	DEFXX;
-	Region region;
-	XRectangle r;
-
-	if ( !XF_IN_PAINT(XX))
-		return false;
-
-	SORT( clipRect. left, clipRect. right);
-	SORT( clipRect. bottom, clipRect. top);
-	r. x = clipRect. left;
-	r. y = REVERT( clipRect. top);
-	r. width = clipRect. right - clipRect. left+1;
-	r. height = clipRect. top - clipRect. bottom+1;
-	XX-> clip_rect = r;
-	XX-> clip_mask_extent. x = r. width;
-	XX-> clip_mask_extent. y = r. height;
-	region = XCreateRegion();
-	XUnionRectWithRegion( &r, region, region);
-	if ( XX-> paint_region)
-		XIntersectRegion( region, XX-> paint_region, region);
-	if ( XX-> btransform. x != 0 || XX-> btransform. y != 0) {
-		XOffsetRegion( region, XX-> btransform. x, -XX-> btransform. y);
-	}
-	XSetRegion( DISP, XX-> gc, region);
-	if ( XX-> flags. kill_current_region) 
-		XDestroyRegion( XX-> current_region);
-	XX-> flags. kill_current_region = 1;
-	XX-> current_region = region;
-	XX-> flags. xft_clip = 0;
-#ifdef USE_XFT
-	if ( XX-> xft_drawable) prima_xft_update_region( self);
-#endif   
-#ifdef HAVE_X11_EXTENSIONS_XRENDER_H
-	if ( XX-> argb_picture ) XRenderSetPictureClipRegion(DISP, XX->argb_picture, region);
-#endif
-	return true;
-}
-
 Bool
 apc_gp_set_back_color( Handle self, Color color)
 {
