@@ -849,9 +849,9 @@ apc_show_message( const char * message, Bool utf8)
 	/* multi-monitor centering */
 	{
 		int i, nrects = 0;
-		Rect2 *best = nil, *rects = apc_application_get_monitor_rects( application, &nrects);
+		Box *best = nil, *rects = apc_application_get_monitor_rects( application, &nrects);
 		for ( i = 0; i < nrects; i++) {
-				Rect2 * curr = rects + i;
+				Box * curr = rects + i;
 				if ( best == nil || best-> x > curr->x || best->y > curr->y)
 						best = curr;
 		}
