@@ -7,6 +7,7 @@
 #include "File.h"
 #include "Menu.h"
 #include "Image.h"
+#include "Region.h"
 #include "Window.h"
 #include "Application.h"
 
@@ -20,6 +21,7 @@ extern "C" {
 #define var (( PWidget) self)->
 #define HANDLE sys handle
 #define DHANDLE(x) dsys(x) handle
+#define GET_REGION(obj) (&(dsys(obj)s.region))
 
 #define WinShowWindow(WND) SetWindowPos( WND, nil, 0, 0, 0, 0, SWP_NOMOVE|SWP_NOSIZE|SWP_NOZORDER|SWP_SHOWWINDOW|SWP_NOACTIVATE);
 #define WinHideWindow(WND) SetWindowPos( WND, nil, 0, 0, 0, 0, SWP_NOMOVE|SWP_NOSIZE|SWP_NOZORDER|SWP_HIDEWINDOW);
@@ -327,14 +329,14 @@ apc_application_get_size( Handle self)
 typedef struct {
 	int nrects;
 	int max_height;
-	Rect2 rects[PRIMA_MAX_MONITORS];
+	Box rects[PRIMA_MAX_MONITORS];
 } EnumMonitorData;
 
 static BOOL
 _enum_monitors( HMONITOR monitor, HDC dc, LPRECT rect, LPARAM data)
 {
 	EnumMonitorData * d;
-	Rect2 * current;
+	Box * current;
 
 	d = ( EnumMonitorData * ) data;
 	if ( d-> nrects >= PRIMA_MAX_MONITORS ) return false;
@@ -350,21 +352,21 @@ _enum_monitors( HMONITOR monitor, HDC dc, LPRECT rect, LPARAM data)
 	return true;
 }
 
-Rect2 *
+Box *
 apc_application_get_monitor_rects( Handle self, int * nrects)
 {
 	int i;
-	Rect2 * ret;
+	Box * ret;
 	EnumMonitorData d = {0,0};
 
 	EnumDisplayMonitors( NULL, NULL, (MONITORENUMPROC) _enum_monitors, (LPARAM) &d);
 	if ( d. nrects == 0) return NULL;
-	if (!(ret = malloc( d.nrects * sizeof(Rect2) )))
+	if (!(ret = malloc( d.nrects * sizeof(Box) )))
 		return NULL;
 
 	for ( i = 0; i < d.nrects; i++)
 		d.rects[i]. y = d.max_height - d.rects[i]. y;
-	memcpy( ret, d.rects, d.nrects * sizeof(Rect2));
+	memcpy( ret, d.rects, d.nrects * sizeof(Box));
 	*nrects = d.nrects;
 	return ret;
 }
@@ -1525,11 +1527,21 @@ apc_window_set_effects( Handle self, HV * effects )
 		profile = (HV*) SvRV(sv);
 		if ( pexist(enable) )                  enable                  = pget_B(enable);
 		if ( pexist(transition_on_maximized) ) transition_on_maximized = pget_B(transition_on_maximized);
-		if ( pexist(mask) )                    mask                    = region_create( pget_H(mask));
+		if ( pexist(mask) ) {
+			Handle region = pget_H(mask);
+			if ( region && kind_of(region, CRegion)){
+				mask = CreateRectRgn(0,0,0,0);
+				CombineRgn( mask, GET_REGION(region)->region, NULL, RGN_COPY);
+				OffsetRgn( mask, 0, sys lastSize.y - GET_REGION(region)->height );
+			}
+		}
 	}
 	sys s. window. effects = effects;
 
-	return set_dwm_blur( HANDLE, enable, mask, transition_on_maximized);
+	ok = set_dwm_blur( HANDLE, enable, mask, transition_on_maximized);
+	if ( mask != (HRGN) -1 )
+		DeleteObject(mask);
+	return ok;
 }
 
 Bool
@@ -2339,48 +2351,24 @@ apc_widget_get_shape( Handle self, Handle mask)
 {
 	HRGN rgn;
 	int res;
-	HBITMAP bm, bmSave;
-	HBRUSH  brSave;
-	HDC dc;
-	XBITMAPINFO xbi;
-	BITMAPINFO * bi;
+	RECT rect;
 
-	objCheck false;
-	rgn = CreateRectRgn(0,0,0,0);
+	if ( !mask ) {
+		rgn = CreateRectRgn(0,0,0,0);
+		res = GetWindowRgn( HANDLE, rgn);
+		res = GetClipRgn( sys ps, rgn );
+		DeleteObject(rgn);
+		return res != ERROR;
+	}
 
+	rgn = GET_REGION(mask)-> region;
 	res = GetWindowRgn( HANDLE, rgn);
-	if ( res == ERROR) {
-		DeleteObject( rgn);
+	if ( res == ERROR)
 		return false;
-	}
-	if ( !mask) {
-		DeleteObject( rgn);
-		return true;
-	}
 
-	CImage( mask)-> create_empty( mask, sys extraBounds. x, sys extraBounds. y, imBW);
-
-	if (!( dc = dc_compat_alloc(0))) return true;
-	if ( !( bm = CreateBitmap( PImage( mask)-> w, PImage( mask)-> h, 1, 1, nil))) {
-		dc_compat_free();
-		return true;
-	}
-
-	bmSave = SelectObject( dc, bm);
-	brSave = SelectObject( dc, CreateSolidBrush( RGB(0,0,0)));
-	Rectangle( dc, 0, 0, PImage( mask)-> w, PImage( mask)-> h);
-	DeleteObject( SelectObject( dc, CreateSolidBrush( RGB( 255, 255, 255))));
-	SetViewportOrgEx( dc, -sys extraPos. x, -sys extraPos. y, NULL);
-	PaintRgn( dc, rgn);
-	DeleteObject( SelectObject( dc, brSave));
-
-	bi = image_fill_bitmap_info( mask, &xbi, BM_BITMAP);
-	if ( !GetDIBits( dc, bm, 0, PImage( mask)-> h, PImage( mask)-> data, bi, DIB_RGB_COLORS)) apiErr;
-	SelectObject( dc, bmSave);
-	DeleteObject( bm);
-	dc_compat_free();
-
-	DeleteObject( rgn);
+	GetRgnBox(rgn, &rect);
+	OffsetRgn( rgn, -sys extraPos. x, -sys extraPos. y);
+	GET_REGION(mask)-> height = sys lastSize. y - rect.top;
 
 	return true;
 }
@@ -2803,10 +2791,10 @@ Bool
 apc_widget_set_shape( Handle self, Handle mask)
 {
 	HRGN rgn = nil;
+	RECT xr;
 	objCheck false;
 
-	rgn = region_create( mask);
-	if ( !rgn) {
+	if ( !mask) {
 		if ( sys className == WC_FRAME && is_apt(aptLayered))
 			SetWindowRgn((HWND) var handle, nil, true);
 		else
@@ -2815,13 +2803,18 @@ apc_widget_set_shape( Handle self, Handle mask)
 		return true;
 	}
 
-	sys extraBounds. x = PImage( mask)-> w;
-	sys extraBounds. y = PImage( mask)-> h;
+
+	rgn = CreateRectRgn(0,0,0,0);
+	CombineRgn( rgn, GET_REGION(mask)->region, NULL, RGN_COPY);
+	GetRgnBox( rgn, &xr);
+	sys extraBounds. x = xr. right - 1;
+	sys extraBounds. y = GET_REGION(mask)->height;
 	if ( sys className == WC_FRAME && !is_apt(aptLayered)) {
 		Point delta = get_window_borders( sys s. window. borderStyle);
 		Point sz    = apc_widget_get_size( self);
 		Point p     = sys extraBounds;
 		HRGN  r1, r2;
+
 		OffsetRgn( rgn, delta.x, sz. y - p.y - delta.y);
 		sys extraPos. x = delta.x;
 		sys extraPos. y = sz. y - p.y - delta.y;
@@ -2834,6 +2827,7 @@ apc_widget_set_shape( Handle self, Handle mask)
 		DeleteObject( r2);
 		if ( !SetWindowRgn( HANDLE, rgn, true))
 			apiErrRet;
+		DeleteObject(rgn);
 	} else if ( sys className == WC_FRAME ) {
 		sys extraPos. x = sys extraPos. y = 0;
 		if ( !SetWindowRgn((HWND) var handle, rgn, true))
@@ -2843,6 +2837,7 @@ apc_widget_set_shape( Handle self, Handle mask)
 		if ( !SetWindowRgn( HANDLE, rgn, true))
 			apiErrRet;
 	}
+	DeleteObject(rgn);
 
 	if ( is_apt(aptMovePending)) {
 		apt_clear(aptMovePending);
